@@ -8,10 +8,7 @@ import io
 import typing
 from typing import Any, Optional, Union
 
-from borb.io.read.read_base_transformer import (
-    ReadBaseTransformer,
-    ReadTransformerContext,
-)
+from borb.io.read.read_base_transformer import ReadBaseTransformer, ReadTransformerState
 from borb.io.read.types import AnyPDFType, Decimal
 from borb.pdf.canvas.event.event_listener import EventListener
 
@@ -33,7 +30,7 @@ class ReadNumberTransformer(ReadBaseTransformer):
         self,
         object_to_transform: Union[io.BufferedIOBase, io.RawIOBase, AnyPDFType],
         parent_object: Any,
-        context: Optional[ReadTransformerContext] = None,
+        context: Optional[ReadTransformerState] = None,
         event_listeners: typing.List[EventListener] = [],
     ) -> Any:
         """
