@@ -4,6 +4,7 @@ from pathlib import Path
 from borb.pdf.document import Document
 from borb.pdf.page.page import Page
 from borb.pdf.pdf import PDF
+from tests.test_util import compare_visually_to_ground_truth
 
 
 class TestWriteEmptyDocument(unittest.TestCase):
@@ -38,7 +39,8 @@ class TestWriteEmptyDocument(unittest.TestCase):
         with open(file, "wb") as pdf_file_handle:
             PDF.dumps(pdf_file_handle, pdf)
 
-        return True
+        # compare visually
+        compare_visually_to_ground_truth(self.output_dir / "output.pdf")
 
 
 if __name__ == "__main__":
