@@ -2,6 +2,7 @@ import os
 import unittest
 from pathlib import Path
 
+from borb.io.write.write_base_transformer import WriteTransformerState
 from borb.pdf.pdf import PDF
 from borb.toolkit.image.image_format_optimization import ImageFormatOptimization
 
@@ -29,6 +30,11 @@ class TestOptimizeImages(unittest.TestCase):
         with open(output_file, "wb") as pdf_file_handle:
             PDF.dumps(pdf_file_handle, doc)
 
+        # check WriteTransformerState
+        assert (
+            WriteTransformerState().compression_level == 9
+        ), "WriteTransformerState.compression_level should be set at 9 for optimal results!"
+
         # check whether output_file is smaller than input_file
         file_size_001: int = os.path.getsize(input_file)
         file_size_002: int = os.path.getsize(output_file)
